summaryrefslogtreecommitdiff
path: root/src/mongo/s/version_mongos.h
diff options
context:
space:
mode:
authorMax Hirschhorn <max.hirschhorn@mongodb.com>2020-03-22 20:33:03 -0400
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-03-23 00:49:46 +0000
commit79a8452b2a813b796059e5eab6c18f685283ce08 (patch)
treebd5012bda9b1561f741c46bfadc7363837ad3d0e /src/mongo/s/version_mongos.h
parentc91a2f5932ac08ca28b25ce11b8ac4949552e271 (diff)
downloadmongo-79a8452b2a813b796059e5eab6c18f685283ce08.tar.gz
Revert "SERVER-46765 fix '--version' & '--sysinfo', which use kPlain logging"
This reverts commit cddfeb0c7cb137d46b14da18a7cfd4905bfab87f.
Diffstat (limited to 'src/mongo/s/version_mongos.h')
-rw-r--r--src/mongo/s/version_mongos.h11
1 files changed, 3 insertions, 8 deletions
diff --git a/src/mongo/s/version_mongos.h b/src/mongo/s/version_mongos.h
index 5a9bde68623..c688b075abb 100644
--- a/src/mongo/s/version_mongos.h
+++ b/src/mongo/s/version_mongos.h
@@ -27,17 +27,12 @@
* it in the license file.
*/
-#include <iosfwd>
-
namespace mongo {
/**
* Outputs the version of MongoS as part of server startup.
* Goes to `os` if nonnull, else to LOGV2.
*
* NOTE: Outputs the version of MongoS to `os` (as part of the --version option),
* which reports different data than if `os` is null!
*/
-void logShardingVersionInfo(std::ostream* os);
+void printShardingVersionInfo(bool isForVersionReportingOnly);
} // namespace mongo
@@ -27,17 +27,12 @@
namespace mongo {
/**
- * Outputs the version of MongoS as part of server startup.
- * Goes to `os` if nonnull, else to LOGV2.
- *
- * NOTE: Outputs the version of MongoS to `os` (as part of the --version option),
- * which reports different data than if `os` is null!
+ * Outputs the version of MongoS either to the standard output (as part of the --version option,
+ * which case isForVersionReportingOnly = true) or to the log file as part of server startup.
*/